======
Models
======

Category
========

**parent**
	The category's parent category. Leave this blank for an Category Tree.

**name**
	The name of the category.

**thumbnail**
 	An optional thumbnail, that is uploaded to ``CATEGORY_SETTINGS['THUMBNAIL_UPLOAD_PATH']`` via ``CATEGORY_SETTINGS['THUMBNAIL_STORAGE']``\ .

**thumbnail_width**
	The thumbnail width.

**thumbnail_height**
	The thumbnail height.

**order**
	The order of this category in the listing

**slug**
	A slug created from the name field

**alternate_title**
	An alternative title to use on pages with this category.

**alternate_url**
	An alternative URL to use instead of the one derived from the category hierarchy.

**description**
	An optional longer description of the category.

**meta_keywords**
	Comma-separated keywords for search engines.

**meta_extra**
	(Advanced) Any additional HTML to be placed verbatim in the ``<head>``
